.. wasp-general documentation master file, created by
   sphinx-quickstart on Wed Aug 24 15:02:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to wasp-general's documentation!
=========================================

Contents:

.. toctree::
   :maxdepth: 2
   
   introduction
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

